======
os-vif
======

.. toctree::
   :maxdepth: 2

   vif_types
   host_info
   usage
   plugins/ovs
   plugins/linux-bridge
   glossary

`os-vif` is a library for plugging and unplugging virtual interfaces (VIFs) in
OpenStack. It provides:

- Versioned objects that represent various types of virtual interfaces and
  their components

- Base VIF plugin class that supplies a ``plug()`` and ``unplug()`` interface

- Plugins for two networking backends - Open vSwitch and Linux Bridge

`os-vif` is intended to define a common model for representing VIF types in
OpenStack. With the exception of the two included plugins, all plugins for
other networking backends are maintained in separate code repositories.
